embedded

package
v0.0.33 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 1, 2025 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Overview

Package embedded provides access to embedded assets for the sketch binary. The native binary (outie) embeds only the linux binary. The linux binary (innie) embeds only the webui assets.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func LinuxBinary

func LinuxBinary(arch string) []byte

LinuxBinary returns the embedded linux binary.

func WebUIFS

func WebUIFS() fs.FS

WebUIFS returns the embedded webui filesystem for direct serving

Types

This section is empty.

Jump to